@@ -121,7 +121,7 @@ class GSCNodeFunctionCaller:
         sio.emit("oncnodefunction", {"target": target, "data": encoded})
 
     def sendcnodefunction(self, target, msg):
-        time.sleep(0.01)
+        time.sleep(self.gsdbs.credentials["cnodesendsleep"])
         self._pool.apply_async(self.emitFunction,
                                args=[self.sio, target, msg],
                                callback=self.on_success,
